@@ -10,14 +10,14 @@ sub config { $config->{$_[1]} }
 sub set_config { $config->{$_[1]} = $_[2] }
 sub set_feature { $features->{$_[1]} = 0+!!$_[2] }  # Constrain to 1 or 0
 
-sub auto_feature_names { grep !exists $features->{$_}, keys %$auto_features }
+sub auto_feature_names { sort grep !exists $features->{$_}, keys %$auto_features }
 
 sub feature_names {
-  my @features = (keys %$features, auto_feature_names());
+  my @features = (sort keys %$features, auto_feature_names());
   @features;
 }
 
-sub config_names  { keys %$config }
+sub config_names  { sort keys %$config }
 
 sub write {
   my $me = __FILE__;
@@ -53,18 +53,13 @@ sub feature {
 
   my $info = $auto_features->{$key} or return 0;
 
-  # Under perl 5.005, each(%$foo) isn't working correctly when $foo
-  # was reanimated with Data::Dumper and eval().  Not sure why, but
-  # copying to a new hash seems to solve it.
-  my %info = %$info;
-
   require Module::Build;  # XXX should get rid of this
-  while (my ($type, $prereqs) = each %info) {
+  foreach my $type (sort keys %$info) {
+    my $prereqs = $info->{$type};
     next if $type eq 'description' || $type eq 'recommends';
 
-    my %p = %$prereqs;  # Ditto here.
-    while (my ($modname, $spec) = each %p) {
-      my $status = Module::Build->check_installed_status($modname, $spec);
+    foreach my $modname (sort keys %$prereqs) {
+      my $status = Module::Build->check_installed_status($modname, $prereqs->{$modname});
       if ((!$status->{ok}) xor ($type =~ /conflicts$/)) { return 0; }
       if ( ! eval "require $modname; 1" ) { return 0; }
     }
@@ -165,23 +160,23 @@ authorship claim or copyright claim to the contents of C<Alien::SDL::ConfigData>
 __DATA__
 do{ my $x = [
        {
-         'build_os' => 'linux',
-         'build_prefix' => 'sharedir/1.446_54145893',
-         'build_params' => {
-                             'prefix' => '/usr',
-                             'title' => 'Already installed SDL ver=1.2.15 path=/usr',
-                             'script' => 'sdl-config',
-                             'buildtype' => 'use_config_script'
-                           },
-         'additional_libs' => '-Wl,-rpath,/usr/local/lib -Wl,-rpath,/usr/lib -L/usr/local/lib -L/usr/lib',
-         'additional_cflags' => '-I/usr/include/smpeg -I/usr/include -I/usr/include -I/usr/local/include',
+         'additional_cflags' => '-I/usr/include/smpeg -I/usr/include -I/usr/local/include -I/usr/include',
+         'additional_libs' => '-L/usr/lib -L/usr/local/lib -Wl,-rpath,/usr/lib -Wl,-rpath,/usr/local/lib',
          'build_arch' => 'armv5tel-linux-thread-multi',
+         'build_cc' => 'cc',
+         'build_os' => 'linux',
+         'build_params' => {
+                             'buildtype' => 'use_config_script',
+                             'prefix' => '/usr',
+                             'script' => 'sdl-config',
+                             'title' => 'Already installed SDL ver=1.2.15 path=/usr'
+                           },
+         'build_prefix' => 'sharedir/1.446_54145893',
          'config' => {
                        'ld_paths' => [],
                        'ld_shared_libs' => [],
                        'ld_shlib_map' => {}
                      },
-         'build_cc' => 'cc',
          'script' => 'sdl-config'
        },
        {},
